==> monocdk-1.106.1.tar.gz: package/lib/aws-elasticloadbalancingv2/lib/shared/base-listener.d.ts <==
import * as cxschema from "../../../cloud-assembly-schema";
import { Resource } from "../../../core";
import * as cxapi from "../../../cx-api";
import { Construct } from 'constructs';
import { IListenerAction } from './listener-action';
/**
 * (experimental) Options for listener lookup.
 *
 * @experimental
 */
export interface BaseListenerLookupOptions {
    /**
     * (experimental) Filter listeners by associated load balancer arn.
     *
     * @default - does not filter by load balancer arn
     * @experimental
     */
    readonly loadBalancerArn?: string;
    /**
     * (experimental) Filter listeners by associated load balancer tags.
     *
     * @default - does not filter by load balancer tags
     * @experimental
     */
    readonly loadBalancerTags?: Record<string, string>;
    /**
     * (experimental) Filter listeners by listener port.
     *
     * @default - does not filter by listener port
     * @experimental
     */
    readonly listenerPort?: number;
}
/**
 * Options for querying the load balancer listener context provider
 * @internal
 */
export interface ListenerQueryContextProviderOptions {
    /**
     * User's provided options
     */
    readonly userOptions: BaseListenerLookupOptions;
    /**
     * Type of load balancer expected
     */
    readonly loadBalancerType: cxschema.LoadBalancerType;
    /**
     * ARN of the listener to look up
     * @default - does not filter by listener arn
     */
    readonly listenerArn?: string;
    /**
     * Optional protocol of the listener to look up
     */
    readonly listenerProtocol?: cxschema.LoadBalancerListenerProtocol;
}
/**
 * (experimental) Base class for listeners.
 *
 * @experimental
 */
export declare abstract class BaseListener extends Resource {
    /**
     * Queries the load balancer listener context provider for load balancer
     * listener info.
     * @internal
     */
    protected static _queryContextProvider(scope: Construct, options: ListenerQueryContextProviderOptions): cxapi.LoadBalancerListenerContextResponse;
    /**
     * @experimental
     * @attribute true
     */
    readonly listenerArn: string;
    private defaultAction?;
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string, additionalProps: any);
    /**
     * (experimental) Validate this listener.
     *
     * @experimental
     */
    protected validate(): string[];
    /**
     * Configure the default action
     *
     * @internal
     */
    protected _setDefaultAction(action: IListenerAction): void;
}

==> monocdk-1.185.0.tar.gz: package/lib/aws-elasticloadbalancingv2/lib/shared/base-listener.d.ts <==
import * as cxschema from '../../../cloud-assembly-schema';
import { Resource } from '../../../core';
import * as cxapi from '../../../cx-api';
import { Construct } from 'constructs';
import { IListenerAction } from './listener-action';
/**
 * Options for listener lookup
 */
export interface BaseListenerLookupOptions {
    /**
     * Filter listeners by associated load balancer arn
     * @default - does not filter by load balancer arn
     */
    readonly loadBalancerArn?: string;
    /**
     * Filter listeners by associated load balancer tags
     * @default - does not filter by load balancer tags
     */
    readonly loadBalancerTags?: Record<string, string>;
    /**
     * Filter listeners by listener port
     * @default - does not filter by listener port
     */
    readonly listenerPort?: number;
}
/**
 * Options for querying the load balancer listener context provider
 * @internal
 */
export interface ListenerQueryContextProviderOptions {
    /**
     * User's provided options
     */
    readonly userOptions: BaseListenerLookupOptions;
    /**
     * Type of load balancer expected
     */
    readonly loadBalancerType: cxschema.LoadBalancerType;
    /**
     * ARN of the listener to look up
     * @default - does not filter by listener arn
     */
    readonly listenerArn?: string;
    /**
     * Optional protocol of the listener to look up
     */
    readonly listenerProtocol?: cxschema.LoadBalancerListenerProtocol;
}
/**
 * Base class for listeners
 */
export declare abstract class BaseListener extends Resource {
    /**
     * Queries the load balancer listener context provider for load balancer
     * listener info.
     * @internal
     */
    protected static _queryContextProvider(scope: Construct, options: ListenerQueryContextProviderOptions): cxapi.LoadBalancerListenerContextResponse;
    /**
     * @attribute
     */
    readonly listenerArn: string;
    private defaultAction?;
    constructor(scope: Construct, id: string, additionalProps: any);
    /**
     * Validate this listener
     */
    protected validate(): string[];
    /**
     * Configure the default action
     *
     * @internal
     */
    protected _setDefaultAction(action: IListenerAction): void;
}
